
import{stdout}from"node:process";

import{execa}from"execa";
import nvexeca from"nvexeca";

import{cleanupProcesses}from"./cleanup.js";
import{getColorOptions}from"./colors.js";
import{printVersions}from"./dry.js";
import{handleParallelError}from"./error.js";
import{printVersionHeader}from"./header.js";
import{writeProcessOutput}from"./output.js";
import{getParallelStdinOptions}from"./stdin.js";


export const runParallel=async({
versionRanges,
command,
args,
continueOpt,
opts
})=>{
if(command===undefined){
return printVersions(versionRanges,opts);
}

const stdinOptions=await getParallelStdinOptions();
const colorOptions=getColorOptions();
const optsA={
...opts,
dry:true,
...stdinOptions,
...colorOptions,
stdout:"pipe",
stderr:"pipe",
buffer:true,
all:true,
stripFinalNewline:true,
reject:true
};

const versions=await startProcesses({
versionRanges,
command,
args,
opts:optsA
});

const state={};
await Promise.all([
cleanupProcesses(versions,continueOpt,state),
runProcesses(versions,continueOpt,state)]);


return state.exitCode;
};




const startProcesses=async({versionRanges,command,args,opts})=>{
const versions=await Promise.all(
versionRanges.map((versionRange)=>
nvexeca(versionRange,command,args,opts)));


const versionsA=versions.map(startProcess);
return versionsA;
};

const startProcess=({versionRange,command,args,execaOptions})=>{
const childProcess=execa(command,args,execaOptions);
return{childProcess,versionRange};
};



const runProcesses=async(versions,continueOpt,state)=>{

let index=0;


for await(const{childProcess,versionRange}of versions){
const shouldStop=await runProcess({
childProcess,
versionRange,
continueOpt,
state,
index
});





if(shouldStop){
return;
}


index+=1;
}
};

const runProcess=async({
childProcess,
versionRange,
continueOpt,
state,
index
})=>{
printVersionHeader(versionRange);




if(index===0){
childProcess.all.pipe(stdout);
}

try{
const{all}=await childProcess;
writeProcessOutput(all,stdout,index);
}catch(error){
await handleParallelError({
error,
versionRange,
continueOpt,
state,
index
});
return!continueOpt;
}
};
//# sourceMappingURL=parallel.js.map