import{execa}from"execa";
import nvexeca from"nvexeca";

import{printVersions}from"./dry.js";
import{handleSerialError}from"./error.js";
import{printVersionHeader}from"./header.js";
import{getSerialStdinOptions}from"./stdin.js";


export const runSerial=async({
versionRanges,
command,
args,
opts,
continueOpt
})=>{
if(command===undefined){
return printVersions(versionRanges,opts);
}

const stdinOptions=await getSerialStdinOptions();
const optsA={
...opts,
dry:true,
...stdinOptions,
stdout:"inherit",
stderr:"inherit",
reject:true,
buffer:false
};

const versions=await Promise.all(
versionRanges.map((versionRange)=>
nvexeca(versionRange,command,args,optsA)));



const state={};
await runProcesses({versions,state,continueOpt});
return state.exitCode;
};

const runProcesses=async({versions,state,continueOpt})=>{

for(const{versionRange,command,args,execaOptions}of versions){
printVersionHeader(versionRange);


const shouldStop=await runProcess({
versionRange,
command,
args,
execaOptions,
state,
continueOpt
});





if(shouldStop){
return;
}
}
};

const runProcess=async({
versionRange,
command,
args,
execaOptions,
state,
continueOpt
})=>{
try{
await execa(command,args,execaOptions);
}catch(error){
handleSerialError(error,versionRange,state);
return!continueOpt;
}
};
//# sourceMappingURL=serial.js.map